@@ -10,7 +10,18 @@ def run_deno_cmd(cmd):
     return run_cmd(str(Path.home()) + "/.deno/bin/" + cmd)
 
 def print_run_cmd(cmd):
-    print(run_cmd(cmd))
+    import subprocess
+    # http://blog.kagesenshi.org/2008/02/teeing-python-subprocesspopen-output.html
+    p = subprocess.Popen(cmd, shell=True, stdout=subprocess.PIPE,
+                         stderr=subprocess.STDOUT, encoding='utf-8', errors='replace')
+    stdout_buffer = []
+    while True:
+        line = p.stdout.readline()
+        stdout_buffer.append(line)
+        print(line, end='')
+        if line == '' and p.poll() != None:
+            break
+    return ''.join(stdout_buffer)
 
 def create_text_file(file_name, file_content):
     with open(file_name,"w") as file:
